@@ -31,12 +31,12 @@ pub struct GaussianInt<T: PrimInt + Integer>(pub Complex<T>);
 /// # Example
 ///
 /// ```
-/// use gaussiant::{GaussianInt, gaussint};
-/// fn main() {
-///     let z = gaussint!(1, 1);
-///     let _z = gaussint!(1, -1);
-///     assert_eq!(z * _z, gaussint!(2, 0));
-/// }
+/// # use gaussiant::{GaussianInt, gaussint};
+/// # fn main() {
+/// let z = gaussint!(1, 1);
+/// let _z = gaussint!(1, -1);
+/// assert_eq!(z * _z, gaussint!(2, 0));
+/// # }
 /// ```
 #[macro_export]
 macro_rules! gaussint {
@@ -423,21 +423,57 @@ where
 
 impl<T: PrimInt + Integer> std::fmt::Display for GaussianInt<T> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let one = T::one();
         let zero = T::zero();
+        // Can't do -one because self isn't necessarily `Signed`
+        let im_is_neg_one = self.0.im + one == zero;
+
+        // a
+        if self.0.im == zero {
+            return write!(f, "{}", self.0.re.to_isize().unwrap());
+        }
+        // i
+        if self.0.re == zero && self.0.im == T::one() {
+            return write!(f, "i");
+        }
+        // -i
+        if self.0.re == zero && im_is_neg_one {
+            return write!(f, "-i");
+        }
+        // bi
+        if self.0.re == zero && !im_is_neg_one {
+            return write!(f, "{}i", self.0.im.to_isize().unwrap());
+        }
+        // a+i
+        if self.0.im == one {
+            return write!(f, "{}+i", self.0.re.to_isize().unwrap());
+        }
+
         if self.0.im < zero {
-            write!(
-                f,
-                "{}{}i",
-                self.0.re.to_isize().unwrap(),
-                self.0.im.to_isize().unwrap()
-            )
+            // -i
+            if self.0.re == zero && im_is_neg_one {
+                return write!(f, "-i");
+            }
+            // a-i
+            if self.0.im + one == zero {
+                write!(f, "{}-i", self.0.re.to_isize().unwrap(),)
+            } else {
+                // a-bi
+                return write!(
+                    f,
+                    "{}{}i",
+                    self.0.re.to_isize().unwrap(),
+                    self.0.im.to_isize().unwrap()
+                );
+            }
         } else {
-            write!(
+            // a+bi
+            return write!(
                 f,
                 "{}+{}i",
                 self.0.re.to_isize().unwrap(),
                 self.0.im.to_isize().unwrap()
-            )
+            );
         }
     }
 }
