@@ -410,6 +410,31 @@ mod tests {
         assert!(!z1.is_associated(z2));
     }
 
+    #[test]
+    #[rustfmt::skip]
+    fn display() {
+        assert_eq!(format!("{}", gaussint!(0, 0)),    "0");
+        assert_eq!(format!("{}", gaussint!(1, 0)),    "1");
+        assert_eq!(format!("{}", gaussint!(-1, 0)),  "-1");
+        assert_eq!(format!("{}", gaussint!(0, 1)),    "i");
+        assert_eq!(format!("{}", gaussint!(0, -1)),  "-i");
+        assert_eq!(format!("{}", gaussint!(1, 1)),  "1+i");
+        assert_eq!(format!("{}", gaussint!(1, -1)), "1-i");
+        assert_eq!(format!("{}", gaussint!(2, 0)),    "2");
+        assert_eq!(format!("{}", gaussint!(-2, 0)),  "-2");
+        assert_eq!(format!("{}", gaussint!(2, 1)),  "2+i");
+        assert_eq!(format!("{}", gaussint!(2, -1)), "2-i");
+        assert_eq!(format!("{}", gaussint!(2, 3)), "2+3i");
+        assert_eq!(format!("{}", gaussint!(2, -3)),"2-3i");
+
+        assert_eq!(format!("{}", gaussint!(0_usize, 0_usize)),  "0");
+        assert_eq!(format!("{}", gaussint!(1_usize, 0_usize)),  "1");
+        assert_eq!(format!("{}", gaussint!(0_usize, 1_usize)),  "i");
+        assert_eq!(format!("{}", gaussint!(2_usize, 0_usize)),  "2");
+        assert_eq!(format!("{}", gaussint!(1_usize, 1_usize)),"1+i");
+        assert_eq!(format!("{}", gaussint!(2_usize, 1_usize)),"2+i");
+    }
+
     #[test]
     #[rustfmt::skip]
     fn from_str() {
